| Title: | The Distributed Local PCA Algorithm |
|---|---|
| Description: | Algorithm to handle with optimal subset selection for distributed local principal component analysis. The philosophy of the package is described in Guo G. (2020) <doi:10.1080/02331888.2020.1823979>. |
| Authors: | Guangbao Guo [aut, cre]
|
| Maintainer: | Guangbao Guo <[email protected]> |
| License: | MIT + file LICENSE |
| Version: | 0.0.5 |
| Built: | 2026-05-19 10:09:42 UTC |
| Source: | https://github.com/cran/DLPCA |
Application data set
data("Application")data("Application")
The format is: int [1:48, 1:15] 6 9 7 5 6 7 9 9 9 4 ... - attr(*, "dimnames")=List of 2 ..$ : NULL ..$ : chr [1:15] "FL" "APP" "AA" "LA" ...
It is the scoring of 15 indicators on 48 interviewees
data(Application) ## maybe str(Application) ; plot(Application) ...data(Application) ## maybe str(Application) ; plot(Application) ...
Calculate the estimator on the DLPCA method
DLPCA(X = X, n = n, p = p, m = m, K = K, L = L)DLPCA(X = X, n = n, p = p, m = m, K = K, L = L)
X |
is the original data matrix |
n |
is the sample size |
p |
is the number of variables |
m |
is the number of eigenvalues |
K |
is the number of nodes |
L |
is the number of subgroups |
time |
is the time cost |
V |
is the right singular matrix |
Vm |
is the m-right singular matrix |
Smean |
is the mean covariance matrix |
MMSER |
is the mean MSE values of the robust covariance matrix sub-estimators |
MMSES |
is the mean MSE values of the covariance matrix sub-estimators |
MMSEX |
is the mean MSE values of the sub-estimators of the matrix X |
MSER |
is the min MSE values of the robust covariance matrix sub-estimators |
MSES |
is the min MSE values of the covariance matrix sub-estimators |
MSEX |
is the min MSE values of the sub-estimators of the matrix X |
wMSER |
is the location of the min MSE values of the robust covariance matrix sub-estimators |
wMSES |
is the location of the min MSE values of the covariance matrix sub-estimators |
wMSEX |
is the location of the min MSE values of the sub-estimators of the matrix X |
sigm |
is the estimator of the covariance matrix of the matrix X |
data(Application) X=Application n=nrow(Application);p=ncol(Application) m=5;L=4;K=4 DLPCA_result=DLPCA(X=X,n=n,p=p,m=m,K=K,L=L)data(Application) X=Application n=nrow(Application);p=ncol(Application) m=5;L=4;K=4 DLPCA_result=DLPCA(X=X,n=n,p=p,m=m,K=K,L=L)
Gas-Turbine CO and NOx Emission Data in 2011
data("gt2011")data("gt2011")
A data frame with 7411 observations on the following 11 variables.
ATa numeric vector
APa numeric vector
AHa numeric vector
AFDPa numeric vector
GTEPa numeric vector
TITa numeric vector
TATa numeric vector
TEYa numeric vector
CDPa numeric vector
COa numeric vector
NOXa numeric vector
The dataset contains 36733 instances of 11 sensor measures aggregated over one hour, from a gas turbine located in Turkey for the purpose of studying flue gas emissions, namely CO and NOx.
Heysem Kaya, Department of Information and Computing Sciences, Utrecht University, 3584 CC, Utrecht, The Netherlands
data(gt2011)data(gt2011)
Gas-Turbine CO and NOx Emission Data in 2012
data("gt2012")data("gt2012")
A data frame with 7628 observations on the following 11 variables.
ATa numeric vector
APa numeric vector
AHa numeric vector
AFDPa numeric vector
GTEPa numeric vector
TITa numeric vector
TATa numeric vector
TEYa numeric vector
CDPa numeric vector
COa numeric vector
NOXa numeric vector
The dataset contains 36733 instances of 11 sensor measures aggregated over one hour, from a gas turbine located in Turkey for the purpose of studying flue gas emissions, namely CO and NOx.
Heysem Kaya, Department of Information and Computing Sciences, Utrecht University, 3584 CC, Utrecht, The Netherlands
data(gt2012)data(gt2012)
Gas-Turbine CO and NOx Emission Data in 2013
data("gt2013")data("gt2013")
A data frame with 7152 observations on the following 11 variables.
ATa numeric vector
APa numeric vector
AHa numeric vector
AFDPa numeric vector
GTEPa numeric vector
TITa numeric vector
TATa numeric vector
TEYa numeric vector
CDPa numeric vector
COa numeric vector
NOXa numeric vector
The dataset contains 36733 instances of 11 sensor measures aggregated over one hour, from a gas turbine located in Turkey for the purpose of studying flue gas emissions, namely CO and NOx.
Heysem Kaya, Department of Information and Computing Sciences, Utrecht University, 3584 CC, Utrecht, The Netherlands
data(gt2013)data(gt2013)
Gas-Turbine CO and NOx Emission Data in 2014
data("gt2014")data("gt2014")
A data frame with 7158 observations on the following 11 variables.
ATa numeric vector
APa numeric vector
AHa numeric vector
AFDPa numeric vector
GTEPa numeric vector
TITa numeric vector
TATa numeric vector
TEYa numeric vector
CDPa numeric vector
COa numeric vector
NOXa numeric vector
The dataset contains 36733 instances of 11 sensor measures aggregated over one hour, from a gas turbine located in Turkey for the purpose of studying flue gas emissions, namely CO and NOx.
Heysem Kaya, Department of Information and Computing Sciences, Utrecht University, 3584 CC, Utrecht, The Netherlands
data(gt2014)data(gt2014)
Gas-Turbine CO and NOx Emission Data in 2015
data("gt2015")data("gt2015")
A data frame with 7384 observations on the following 11 variables.
ATa numeric vector
APa numeric vector
AHa numeric vector
AFDPa numeric vector
GTEPa numeric vector
TITa numeric vector
TATa numeric vector
TEYa numeric vector
CDPa numeric vector
COa numeric vector
NOXa numeric vector
The dataset contains 36733 instances of 11 sensor measures aggregated over one hour, from a gas turbine located in Turkey for the purpose of studying flue gas emissions, namely CO and NOx.
Heysem Kaya, Department of Information and Computing Sciences, Utrecht University, 3584 CC, Utrecht, The Netherlands
data(gt2015)data(gt2015)
Iris data set
data("Iris")data("Iris")
A data frame with 150 observations on the following 5 variables.
Sepal.lengtha numeric vector
Sepal.widtha numeric vector
Petal.lengtha numeric vector
Petal.widtha numeric vector
Speciesa character vector
It contains 150 samples with 5 variables
Gaspar peninsula in Canada
data(Iris) ## maybe str(Iris) ; plot(Iris) ...data(Iris) ## maybe str(Iris) ; plot(Iris) ...
Caculate the MSE value on PCA
MSEpca(V = V, X = X, n = n, p = p, m = m, K = K, L = L)MSEpca(V = V, X = X, n = n, p = p, m = m, K = K, L = L)
V |
is the right singular matrix |
X |
is the orignal data set |
n |
is the sample size |
p |
is the number of variables |
m |
is the number of eigenvalues |
K |
is the number of nodes |
L |
is the number of subgroups |
MSEpca |
the MSE value on PCA |
data(Application) X=Application n=nrow(Application);p=ncol(Application) m=5;L=4;K=4 DLPCA_result=DLPCA(X=X,n=n,p=p,m=m,K=K,L=L) V=DLPCA_result$V MSEpca_result=MSEpca(V=V,X=X,n=n,p=p,m=m,K=K,L=L) MSE_PCA=MSEpca_result$MSEpcadata(Application) X=Application n=nrow(Application);p=ncol(Application) m=5;L=4;K=4 DLPCA_result=DLPCA(X=X,n=n,p=p,m=m,K=K,L=L) V=DLPCA_result$V MSEpca_result=MSEpca(V=V,X=X,n=n,p=p,m=m,K=K,L=L) MSE_PCA=MSEpca_result$MSEpca